{% load i18n %}
{% load sekizai_tags %}

{% addtoblock "js" %}<script type="text/javascript" src="{{ STATIC_URL }}admin/js/jquery.min.js"></script>{% endaddtoblock %}

{% addtoblock "js" %}
<script type="text/javascript">
    $(document).ready(function(){
        $("#plugin-{{ object.id }}").load('{% url 'ajax_render' object.id %}{{ object.args|safe }}');
    });
</script>
{% endaddtoblock %}

<div id="plugin-{{ object.id }}" class='cms-ajax-text-plugin'>
  <div class='cms-ajax-text-plugin-loading'>
  {% trans "loading..." %}
  </div>
</div>


